"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = require("path");
var treeshake = require("./treeshake");
var Constants = require("../util/constants");
var helpers = require("../util/helpers");
var originalEnv = null;
var baseDir = path_1.join(process.cwd(), 'some', 'dir', 'myApp');
var srcDir = path_1.join(baseDir, 'src');
var main = path_1.join(srcDir, 'app', 'main.js');
var appModule = path_1.join(srcDir, 'app', 'app.module.js');
var nodeModulesDir = path_1.join(baseDir, 'node_modules');
var ionicAngularDir = path_1.join(nodeModulesDir, 'ionic-angular');
var ionicAngularEntryPoint = path_1.join(ionicAngularDir, 'index.js');
var componentDir = path_1.join(ionicAngularDir, 'components');
describe('treeshake', function () {
    beforeEach(function () {
        originalEnv = process.env;
        var env = {};
        env[Constants.ENV_VAR_IONIC_ANGULAR_DIR] = ionicAngularDir;
        env[Constants.ENV_VAR_IONIC_ANGULAR_ENTRY_POINT] = ionicAngularEntryPoint;
        env[Constants.ENV_VAR_SRC_DIR] = srcDir;
        env[Constants.ENV_APP_ENTRY_POINT] = main;
        env[Constants.ENV_APP_NG_MODULE_PATH] = appModule;
        env[Constants.ENV_ACTION_SHEET_COMPONENT_FACTORY_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'action-sheet', 'action-sheet-component.ngfactory.js');
        env[Constants.ENV_ACTION_SHEET_CONTROLLER_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'action-sheet', 'action-sheet-controller.js');
        env[Constants.ENV_ALERT_COMPONENT_FACTORY_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'alert', 'alert-component.ngfactory.js');
        env[Constants.ENV_ALERT_CONTROLLER_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'alert', 'alert-controller.js');
        env[Constants.ENV_LOADING_COMPONENT_FACTORY_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'loading', 'loading-component.ngfactory.js');
        env[Constants.ENV_LOADING_CONTROLLER_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'loading', 'loading-controller.js');
        env[Constants.ENV_MODAL_COMPONENT_FACTORY_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'modal', 'modal-component.ngfactory.js');
        env[Constants.ENV_MODAL_CONTROLLER_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'modal', 'modal-controller.js');
        env[Constants.ENV_PICKER_COMPONENT_FACTORY_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'picker', 'picker-component.ngfactory.js');
        env[Constants.ENV_PICKER_CONTROLLER_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'picker', 'picker-controller.js');
        env[Constants.ENV_POPOVER_COMPONENT_FACTORY_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'popover', 'popover-component.ngfactory.js');
        env[Constants.ENV_POPOVER_CONTROLLER_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'popover', 'popover-controller.js');
        env[Constants.ENV_TOAST_COMPONENT_FACTORY_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'toast', 'toast-component.ngfactory.js');
        env[Constants.ENV_TOAST_CONTROLLER_PATH] = path_1.join(env[Constants.ENV_VAR_IONIC_ANGULAR_DIR], 'components', 'toast', 'toast-controller.js');
        process.env = env;
    });
    afterEach(function () {
        process.env = originalEnv;
    });
    describe('calculateTreeShakeResults', function () {
        it('should remove modules that are only imported by index', function () {
            // arrange
            var dependencyOne = path_1.join(componentDir, 'range.js');
            var dependencyTwo = path_1.join(componentDir, 'radio-button.js');
            var dependencyThree = path_1.join(componentDir, 'check-box.js');
            var dependencyOneSet = new Set();
            dependencyOneSet.add(ionicAngularEntryPoint);
            var dependencyTwoSet = new Set();
            dependencyTwoSet.add(ionicAngularEntryPoint);
            var dependencyThreeSet = new Set();
            dependencyThreeSet.add(ionicAngularEntryPoint);
            var dependencyMap = new Map();
            dependencyMap.set(dependencyOne, dependencyOneSet);
            dependencyMap.set(dependencyTwo, dependencyTwoSet);
            dependencyMap.set(dependencyThree, dependencyThreeSet);
            dependencyMap.set(ionicAngularEntryPoint, new Set());
            // act
            var results = treeshake.calculateUnusedComponents(dependencyMap);
            // assert
            expect(results.updatedDependencyMap.get(dependencyOne)).not.toBeTruthy();
            expect(results.updatedDependencyMap.get(dependencyTwo)).not.toBeTruthy();
            expect(results.updatedDependencyMap.get(dependencyThree)).not.toBeTruthy();
            expect(results.purgedModules.get(dependencyOne)).toBeTruthy();
            expect(results.purgedModules.get(dependencyTwo)).toBeTruthy();
            expect(results.purgedModules.get(dependencyThree)).toBeTruthy();
        });
        it('should remove other components that are imported only by index or other modules that can be removed (only imported by index)', function () {
            // arrange
            var dependencyOne = path_1.join(componentDir, 'range.js');
            var dependencyOneNgFactory = path_1.join(componentDir, 'range.ngfactory.js');
            var dependencyOneHelperOne = path_1.join(componentDir, 'range', 'helperOne.js');
            var dependencyOneHelperTwo = path_1.join(componentDir, 'range', 'helperTwo.js');
            var dependencyTwo = path_1.join(componentDir, 'radio-button.js');
            var dependencyThree = path_1.join(componentDir, 'check-box.js');
            var dependencyFour = path_1.join(componentDir, 'badge.js');
            var dependencyFourNgFactory = path_1.join(componentDir, 'badge.ngfactory.js');
            var appModuleNgFactory = path_1.join(srcDir, 'app', 'app.module.ngfactory.js');
            var alert = path_1.join(componentDir, 'alert', 'alert.js');
            var alertController = path_1.join(componentDir, 'alert', 'alert-controller.js');
            var alertComponent = path_1.join(componentDir, 'alert', 'alert-component.js');
            var alertComponentNgFactory = path_1.join(componentDir, 'alert', 'alert-component.ngfactory.js');
            var actionSheet = path_1.join(componentDir, 'action-sheet', 'action-sheet.js');
            var actionSheetController = path_1.join(componentDir, 'action-sheet', 'action-sheet-controller.js');
            var actionSheetComponent = path_1.join(componentDir, 'action-sheet', 'action-sheet-component.js');
            var actionSheetComponentNgFactory = path_1.join(componentDir, 'action-sheet', 'action-sheet-component.ngfactory.js');
            var home = path_1.join(srcDir, 'pages', 'home.js');
            var homeNgFactory = path_1.join(srcDir, 'pages', 'home.ngfactory.js');
            var appModuleSet = new Set();
            appModuleSet.add(appModuleNgFactory);
            var appModuleNgFactorySet = new Set();
            var homeSet = new Set();
            homeSet.add(appModule);
            homeSet.add(homeNgFactory);
            var homeNgFactorySet = new Set();
            homeNgFactorySet.add(appModuleNgFactory);
            var dependencyOneSet = new Set();
            dependencyOneSet.add(ionicAngularEntryPoint);
            dependencyOneSet.add(dependencyOneNgFactory);
            dependencyOneSet.add(home);
            var dependencyOneNgFactorySet = new Set();
            dependencyOneNgFactorySet.add(homeNgFactory);
            var dependencyTwoSet = new Set();
            dependencyTwoSet.add(ionicAngularEntryPoint);
            var dependencyThreeSet = new Set();
            dependencyThreeSet.add(ionicAngularEntryPoint);
            var dependencyFourSet = new Set();
            dependencyFourSet.add(ionicAngularEntryPoint);
            dependencyFourSet.add(dependencyFourNgFactory);
            dependencyFourSet.add(home);
            var dependencyFourNgFactorySet = new Set();
            dependencyFourNgFactorySet.add(homeNgFactory);
            var indexSet = new Set();
            indexSet.add(home);
            indexSet.add(appModuleNgFactory);
            indexSet.add(appModule);
            var dependencyOneHelperOneSet = new Set();
            dependencyOneHelperOneSet.add(dependencyOne);
            dependencyOneHelperOneSet.add(ionicAngularEntryPoint);
            var dependencyOneHelperTwoSet = new Set();
            dependencyOneHelperTwoSet.add(dependencyOne);
            dependencyOneHelperTwoSet.add(ionicAngularEntryPoint);
            var alertSet = new Set();
            alertSet.add(alertController);
            var alertControllerSet = new Set();
            alertControllerSet.add(ionicAngularEntryPoint);
            alertControllerSet.add(appModuleNgFactory);
            var alertComponentSet = new Set();
            alertComponentSet.add(ionicAngularEntryPoint);
            alertComponentSet.add(alertComponentNgFactory);
            var alertComponentNgFactorySet = new Set();
            alertComponentNgFactorySet.add(appModuleNgFactory);
            var actionSheetSet = new Set();
            actionSheetSet.add(actionSheetController);
            var actionSheetControllerSet = new Set();
            actionSheetControllerSet.add(ionicAngularEntryPoint);
            actionSheetControllerSet.add(appModuleNgFactory);
            actionSheetControllerSet.add(homeNgFactory);
            var actionSheetComponentSet = new Set();
            actionSheetComponentSet.add(ionicAngularEntryPoint);
            actionSheetComponentSet.add(actionSheetComponentNgFactory);
            var actionSheetComponentNgFactorySet = new Set();
            actionSheetComponentNgFactorySet.add(appModuleNgFactory);
            var dependencyMap = new Map();
            dependencyMap.set(appModule, appModuleSet);
            dependencyMap.set(appModuleNgFactory, appModuleNgFactorySet);
            dependencyMap.set(home, homeSet);
            dependencyMap.set(homeNgFactory, homeNgFactorySet);
            dependencyMap.set(dependencyOne, dependencyOneSet);
            dependencyMap.set(dependencyOneNgFactory, dependencyOneNgFactorySet);
            dependencyMap.set(dependencyOneHelperOne, dependencyOneHelperOneSet);
            dependencyMap.set(dependencyOneHelperTwo, dependencyOneHelperTwoSet);
            dependencyMap.set(dependencyTwo, dependencyTwoSet);
            dependencyMap.set(dependencyThree, dependencyThreeSet);
            dependencyMap.set(dependencyFour, dependencyFourSet);
            dependencyMap.set(dependencyFourNgFactory, dependencyFourNgFactorySet);
            dependencyMap.set(ionicAngularEntryPoint, indexSet);
            dependencyMap.set(alert, alertSet);
            dependencyMap.set(alertController, alertControllerSet);
            dependencyMap.set(alertComponent, alertComponentSet);
            dependencyMap.set(alertComponentNgFactory, alertComponentNgFactorySet);
            dependencyMap.set(actionSheet, actionSheetSet);
            dependencyMap.set(actionSheetController, actionSheetControllerSet);
            dependencyMap.set(actionSheetComponent, actionSheetComponentSet);
            dependencyMap.set(actionSheetComponentNgFactory, actionSheetComponentNgFactorySet);
            // act
            var results = treeshake.calculateUnusedComponents(dependencyMap);
            // assert
            expect(results.updatedDependencyMap.get(appModule)).toBeTruthy();
            expect(results.updatedDependencyMap.get(appModuleNgFactory)).toBeTruthy();
            expect(results.updatedDependencyMap.get(home)).toBeTruthy();
            expect(results.updatedDependencyMap.get(homeNgFactory)).toBeTruthy();
            expect(results.updatedDependencyMap.get(dependencyOne)).toBeTruthy();
            expect(results.updatedDependencyMap.get(dependencyOneNgFactory)).toBeTruthy();
            expect(results.updatedDependencyMap.get(dependencyOneHelperOne)).toBeTruthy();
            expect(results.updatedDependencyMap.get(dependencyOneHelperTwo)).toBeTruthy();
            expect(results.updatedDependencyMap.get(dependencyFour)).toBeTruthy();
            expect(results.updatedDependencyMap.get(dependencyFourNgFactory)).toBeTruthy();
            expect(results.updatedDependencyMap.get(actionSheet)).toBeTruthy();
            expect(results.updatedDependencyMap.get(actionSheetController)).toBeTruthy();
            expect(results.updatedDependencyMap.get(actionSheetComponent)).toBeTruthy();
            expect(results.updatedDependencyMap.get(actionSheetComponentNgFactory)).toBeTruthy();
            expect(results.purgedModules.get(dependencyTwo)).toBeTruthy();
            expect(results.purgedModules.get(dependencyThree)).toBeTruthy();
            expect(results.purgedModules.get(alert)).toBeTruthy();
            expect(results.purgedModules.get(alertController)).toBeTruthy();
            expect(results.purgedModules.get(alertComponent)).toBeTruthy();
            expect(results.purgedModules.get(alertComponentNgFactory)).toBeTruthy();
        });
    });
    describe('purgeUnusedImportsAndExportsFromIndex', function () {
        it('should remove the import and export statement', function () {
            // arrange
            var importsToPurge = "\nimport { RangeKnob } from './components/range/range-knob';\nimport { Refresher } from './components/refresher/refresher';\nimport { RefresherContent } from './components/refresher/refresher-content';\n      ";
            var exportsToPurge = "\nexport { RangeKnob } from './components/range/range-knob';\nexport { Refresher } from './components/refresher/refresher';\nexport { RefresherContent } from './components/refresher/refresher-content';\n      ";
            var indexFileContent = "\n      import { ANALYZE_FOR_ENTRY_COMPONENTS, APP_INITIALIZER, ComponentFactoryResolver, Inject, Injector, NgModule, NgZone, Optional } from '@angular/core/index';\nimport { APP_BASE_HREF, Location, LocationStrategy, HashLocationStrategy, PathLocationStrategy, PlatformLocation } from '@angular/common/index';\nimport { DOCUMENT } from '@angular/platform-browser/index';\nimport { FormsModule, ReactiveFormsModule } from '@angular/forms/index';\nimport { HttpModule } from '@angular/http/index';\nimport { CommonModule } from '@angular/common/index';\nimport { ActionSheetController } from './components/action-sheet/action-sheet';\nimport { AlertController } from './components/alert/alert';\nimport { App } from './components/app/app';\nimport { AppRootToken } from './components/app/app-root';\nimport { Config, setupConfig, ConfigToken } from './config/config';\nimport { DeepLinker, setupDeepLinker } from './navigation/deep-linker';\nimport { DomController } from './platform/dom-controller';\nimport { Events, setupProvideEvents } from './util/events';\nimport { Form } from './util/form';\nimport { GestureController } from './gestures/gesture-controller';\nimport { Haptic } from './tap-click/haptic';\nimport { Keyboard } from './platform/keyboard';\nimport { LoadingController } from './components/loading/loading';\nimport { MenuController } from './components/menu/menu-controller';\nimport { ModalController } from './components/modal/modal';\nimport { ModuleLoader, LAZY_LOADED_TOKEN } from './util/module-loader';\nimport { PickerController } from './components/picker/picker';\nimport { Platform, setupPlatform } from './platform/platform';\nimport { PlatformConfigToken, providePlatformConfigs } from './platform/platform-registry';\nimport { PopoverController } from './components/popover/popover';\nimport { SystemJsNgModuleLoader } from './util/system-js-ng-module-loader';\nimport { TapClick, setupTapClick } from './tap-click/tap-click';\nimport { ToastController } from './components/toast/toast';\nimport { registerModeConfigs } from './config/mode-registry';\nimport { registerTransitions } from './transitions/transition-registry';\nimport { TransitionController } from './transitions/transition-controller';\nimport { UrlSerializer, setupUrlSerializer, DeepLinkConfigToken } from './navigation/url-serializer';\nimport { ActionSheetCmp } from './components/action-sheet/action-sheet-component';\nimport { AlertCmp } from './components/alert/alert-component';\nimport { IonicApp } from './components/app/app-root';\nimport { LoadingCmp } from './components/loading/loading-component';\nimport { ModalCmp } from './components/modal/modal-component';\nimport { PickerCmp } from './components/picker/picker-component';\nimport { PopoverCmp } from './components/popover/popover-component';\nimport { ToastCmp } from './components/toast/toast-component';\nimport { Avatar } from './components/avatar/avatar';\nimport { Backdrop } from './components/backdrop/backdrop';\nimport { Badge } from './components/badge/badge';\nimport { One } from './components/badge/badge/one';\nimport { Two } from './components/badge/badge/two';\nimport { Button } from './components/button/button';\nimport { Card } from './components/card/card';\nimport { CardContent } from './components/card/card-content';\nimport { CardHeader } from './components/card/card-header';\nimport { CardTitle } from './components/card/card-title';\nimport { Checkbox } from './components/checkbox/checkbox';\nimport { Chip } from './components/chip/chip';\nimport { ClickBlock } from './util/click-block';\nimport { Content } from './components/content/content';\nimport { DateTime } from './components/datetime/datetime';\nimport { FabButton } from './components/fab/fab';\nimport { FabContainer } from './components/fab/fab-container';\nimport { FabList } from './components/fab/fab-list';\nimport { Col } from './components/grid/column';\nimport { Grid } from './components/grid/grid';\nimport { Row } from './components/grid/row';\nimport { Icon } from './components/icon/icon';\nimport { Img } from './components/img/img';\nimport { InfiniteScroll } from './components/infinite-scroll/infinite-scroll';\nimport { InfiniteScrollContent } from './components/infinite-scroll/infinite-scroll-content';\nimport { Item } from './components/item/item';\nimport { ItemContent } from './components/item/item-content';\nimport { ItemDivider } from './components/item/item-divider';\nimport { ItemGroup } from './components/item/item-group';\nimport { ItemReorder } from './components/item/item-reorder';\nimport { Reorder } from './components/item/reorder';\nimport { ItemSliding } from './components/item/item-sliding';\nimport { ItemOptions } from './components/item/item-options';\nimport { Label } from './components/label/label';\nimport { List } from './components/list/list';\nimport { ListHeader } from './components/list/list-header';\nimport { Menu } from './components/menu/menu';\nimport { MenuClose } from './components/menu/menu-close';\nimport { MenuToggle } from './components/menu/menu-toggle';\nimport { NativeInput } from './components/input/native-input';\nimport { NextInput } from './components/input/next-input';\nimport { Nav } from './components/nav/nav';\nimport { NavPop } from './components/nav/nav-pop';\nimport { NavPopAnchor } from './components/nav/nav-pop-anchor';\nimport { NavPush } from './components/nav/nav-push';\nimport { NavPushAnchor } from './components/nav/nav-push-anchor';\nimport { Navbar } from './components/navbar/navbar';\nimport { Note } from './components/note/note';\nimport { Option } from './components/option/option';\nimport { OverlayPortal } from './components/nav/overlay-portal';\nimport { PickerColumnCmp } from './components/picker/picker-component';\nimport { RadioButton } from './components/radio/radio-button';\nimport { RadioGroup } from './components/radio/radio-group';\nimport { Range } from './components/range/range';\n" + importsToPurge + "\n" + importsToPurge + "\nimport { Scroll } from './components/scroll/scroll';\nimport { Searchbar } from './components/searchbar/searchbar';\nimport { Segment } from './components/segment/segment';\nimport { SegmentButton } from './components/segment/segment-button';\nimport { Select } from './components/select/select';\nimport { ShowWhen } from './components/show-hide-when/show-hide-when';\nimport { HideWhen } from './components/show-hide-when/hide-when';\nimport { Slide } from './components/slides/slide';\nimport { Slides } from './components/slides/slides';\nimport { Spinner } from './components/spinner/spinner';\nimport { Tab } from './components/tabs/tab';\nimport { Tabs } from './components/tabs/tabs';\nimport { TabButton } from './components/tabs/tab-button';\nimport { TabHighlight } from './components/tabs/tab-highlight';\nimport { TextInput } from './components/input/input';\nimport { Thumbnail } from './components/thumbnail/thumbnail';\nimport { Toggle } from './components/toggle/toggle';\nimport { Toolbar } from './components/toolbar/toolbar';\nimport { Header } from './components/toolbar/toolbar-header';\nimport { Footer } from './components/toolbar/toolbar-footer';\nimport { ToolbarItem } from './components/toolbar/toolbar-item';\nimport { ToolbarTitle } from './components/toolbar/toolbar-title';\nimport { Typography } from './components/typography/typography';\nimport { VirtualScroll } from './components/virtual-scroll/virtual-scroll';\nimport { VirtualItem } from './components/virtual-scroll/virtual-item';\nimport { VirtualHeader } from './components/virtual-scroll/virtual-header';\nimport { VirtualFooter } from './components/virtual-scroll/virtual-footer';\n/**\n * Export Components/Directives\n */\nexport { ActionSheet, ActionSheetController } from './components/action-sheet/action-sheet';\nexport { Alert, AlertController } from './components/alert/alert';\nexport { App } from './components/app/app';\nexport { Avatar } from './components/avatar/avatar';\nexport { Backdrop } from './components/backdrop/backdrop';\nexport { Badge } from './components/badge/badge';\nexport { One } from './components/badge/badge/one';\nexport { Two } from './components/badge/badge/two';\nexport { Button } from './components/button/button';\nexport { Card } from './components/card/card';\nexport { CardContent } from './components/card/card-content';\nexport { CardHeader } from './components/card/card-header';\nexport { CardTitle } from './components/card/card-title';\nexport { Checkbox } from './components/checkbox/checkbox';\nexport { Chip } from './components/chip/chip';\nexport { ClickBlock } from './util/click-block';\nexport { Content } from './components/content/content';\nexport { DateTime } from './components/datetime/datetime';\nexport { FabButton } from './components/fab/fab';\nexport { FabContainer } from './components/fab/fab-container';\nexport { FabList } from './components/fab/fab-list';\nexport { Col } from './components/grid/column';\nexport { Grid } from './components/grid/grid';\nexport { Row } from './components/grid/row';\nexport { Ion } from './components/ion';\nexport { Icon } from './components/icon/icon';\nexport { Img } from './components/img/img';\nexport { InfiniteScroll } from './components/infinite-scroll/infinite-scroll';\nexport { InfiniteScrollContent } from './components/infinite-scroll/infinite-scroll-content';\nexport { TextInput } from './components/input/input';\nexport { IonicApp } from './components/app/app-root';\nexport { Item } from './components/item/item';\nexport { ItemContent } from './components/item/item-content';\nexport { ItemDivider } from './components/item/item-divider';\nexport { ItemGroup } from './components/item/item-group';\nexport { ItemReorder } from './components/item/item-reorder';\nexport { Reorder } from './components/item/reorder';\nexport { ItemSliding } from './components/item/item-sliding';\nexport { ItemOptions } from './components/item/item-options';\nexport { Label } from './components/label/label';\nexport { List } from './components/list/list';\nexport { ListHeader } from './components/list/list-header';\nexport { Loading, LoadingController } from './components/loading/loading';\nexport { Menu } from './components/menu/menu';\nexport { MenuClose } from './components/menu/menu-close';\nexport { MenuController } from './components/menu/menu-controller';\nexport { MenuToggle } from './components/menu/menu-toggle';\nexport { MenuType } from './components/menu/menu-types';\nexport { Modal, ModalController } from './components/modal/modal';\nexport { Nav } from './components/nav/nav';\nexport { NavPop } from './components/nav/nav-pop';\nexport { NavPopAnchor } from './components/nav/nav-pop-anchor';\nexport { NavPush } from './components/nav/nav-push';\nexport { NavPushAnchor } from './components/nav/nav-push-anchor';\nexport { Navbar } from './components/navbar/navbar';\nexport { NativeInput } from './components/input/native-input';\nexport { NextInput } from './components/input/next-input';\nexport { Note } from './components/note/note';\nexport { Option } from './components/option/option';\nexport { OverlayPortal } from './components/nav/overlay-portal';\nexport { Picker, PickerController } from './components/picker/picker';\nexport { Popover, PopoverController } from './components/popover/popover';\nexport { RadioButton } from './components/radio/radio-button';\nexport { RadioGroup } from './components/radio/radio-group';\nexport { Range } from './components/range/range';\n" + exportsToPurge + "\n" + exportsToPurge + "\nexport { Scroll } from './components/scroll/scroll';\nexport { Searchbar } from './components/searchbar/searchbar';\nexport { Segment } from './components/segment/segment';\nexport { SegmentButton } from './components/segment/segment-button';\nexport { Select } from './components/select/select';\nexport { ShowWhen } from './components/show-hide-when/show-hide-when';\nexport { DisplayWhen } from './components/show-hide-when/show-hide-when';\nexport { HideWhen } from './components/show-hide-when/hide-when';\nexport { Slide } from './components/slides/slide';\nexport { Slides } from './components/slides/slides';\nexport { Spinner } from './components/spinner/spinner';\nexport { Tab } from './components/tabs/tab';\nexport { TabButton } from './components/tabs/tab-button';\nexport { TabHighlight } from './components/tabs/tab-highlight';\nexport { Tabs } from './components/tabs/tabs';\nexport { TapClick, setupTapClick, isActivatable } from './tap-click/tap-click';\nexport { Toast, ToastController } from './components/toast/toast';\nexport { Toggle } from './components/toggle/toggle';\nexport { ToolbarBase } from './components/toolbar/toolbar';\nexport { Toolbar } from './components/toolbar/toolbar';\nexport { Header } from './components/toolbar/toolbar-header';\nexport { Footer } from './components/toolbar/toolbar-footer';\nexport { ToolbarItem } from './components/toolbar/toolbar-item';\nexport { ToolbarTitle } from './components/toolbar/toolbar-title';\nexport { Thumbnail } from './components/thumbnail/thumbnail';\nexport { Typography } from './components/typography/typography';\nexport { VirtualScroll } from './components/virtual-scroll/virtual-scroll';\n/**\n * Export Providers\n */\nexport { Config, setupConfig, ConfigToken } from './config/config';\nexport { DomController } from './platform/dom-controller';\nexport { Platform, setupPlatform } from './platform/platform';\nexport { Haptic } from './tap-click/haptic';\nexport { DeepLinker } from './navigation/deep-linker';\nexport { NavController } from './navigation/nav-controller';\nexport { NavControllerBase } from './navigation/nav-controller-base';\nexport { NavParams } from './navigation/nav-params';\nexport { DeepLink, DeepLinkMetadata } from './navigation/nav-util';\nexport { UrlSerializer, DeepLinkConfigToken } from './navigation/url-serializer';\nexport { ViewController } from './navigation/view-controller';\nexport { ActionSheetCmp } from './components/action-sheet/action-sheet-component';\nexport { AlertCmp } from './components/alert/alert-component';\nexport { LoadingCmp } from './components/loading/loading-component';\nexport { ModalCmp } from './components/modal/modal-component';\nexport { PickerCmp, PickerColumnCmp } from './components/picker/picker-component';\nexport { PopoverCmp } from './components/popover/popover-component';\nexport { ToastCmp } from './components/toast/toast-component';\n/**\n * Export Utils\n */\nexport { PanGesture } from './gestures/drag-gesture';\nexport { Gesture } from './gestures/gesture';\nexport { SlideEdgeGesture } from './gestures/slide-edge-gesture';\nexport { SlideGesture } from './gestures/slide-gesture';\nexport { BLOCK_ALL, GESTURE_GO_BACK_SWIPE, GESTURE_MENU_SWIPE, GESTURE_ITEM_SWIPE, GESTURE_REFRESHER, GESTURE_TOGGLE, GestureController, GestureDelegate, BlockerDelegate } from './gestures/gesture-controller';\nexport { Events, setupEvents, setupProvideEvents } from './util/events';\nexport { IonicErrorHandler } from './util/ionic-error-handler';\nexport { Keyboard } from './platform/keyboard';\nexport { Form, IonicFormInput, IonicTapInput } from './util/form';\nexport { reorderArray } from './util/util';\nexport { Animation } from './animations/animation';\nexport { PageTransition } from './transitions/page-transition';\nexport { Transition } from './transitions/transition';\n      ";
            // act
            var modulesToPurge = [path_1.join(componentDir, 'range', 'range-knob'),
                path_1.join(componentDir, 'refresher', 'refresher'),
                path_1.join(componentDir, 'refresher', 'refresher-content')];
            var newContent = treeshake.purgeUnusedImportsAndExportsFromIndex(ionicAngularEntryPoint, indexFileContent, modulesToPurge);
            // assert
            expect(newContent).not.toEqual(indexFileContent);
            expect(newContent.indexOf(importsToPurge)).toEqual(-1);
            expect(newContent.indexOf(exportsToPurge)).toEqual(-1);
        });
    });
    describe('purgeComponentNgFactoryImportAndUsage', function () {
        it('should purge the component factory import and usage from the file', function () {
            // arrange
            var knownImport = "import * as import48 from '../../node_modules/ionic-angular/components/action-sheet/action-sheet-component.ngfactory';";
            var knownImport2 = "import * as import49 from '../../node_modules/ionic-angular/components/alert/alert-component.ngfactory';";
            var knownImportUsage = "import48.ActionSheetCmpNgFactory,";
            var knownImportUsage2 = "import49.AlertCmpNgFactory,";
            var knownContent = "\n        /**\n * @fileoverview This file is generated by the Angular template compiler.\n * Do not edit.\n * @suppress {suspiciousCode,uselessCode,missingProperties}\n */\n/* tslint:disable */\nimport * as import0 from '@angular/core/src/linker/ng_module_factory';\nimport * as import1 from './app.module';\nimport * as import2 from '@angular/common/src/common_module';\nimport * as import3 from '@angular/core/src/application_module';\nimport * as import4 from '@angular/platform-browser/src/browser';\nimport * as import5 from '@angular/http/src/http_module';\nimport * as import6 from '@angular/forms/src/directives';\nimport * as import7 from '@angular/forms/src/form_providers';\nimport * as import8 from 'ionic-angular/index';\nimport * as import9 from '@angular/common/src/localization';\nimport * as import10 from 'ionic-angular/platform/dom-controller';\nimport * as import11 from 'ionic-angular/components/menu/menu-controller';\nimport * as import12 from 'ionic-angular/components/app/app';\nimport * as import13 from 'ionic-angular/gestures/gesture-controller';\nimport * as import14 from '@angular/core/src/application_init';\nimport * as import15 from '@angular/core/src/testability/testability';\nimport * as import16 from '@angular/core/src/application_ref';\nimport * as import17 from '@angular/core/src/linker/compiler';\nimport * as import18 from '@angular/platform-browser/src/dom/events/hammer_gestures';\nimport * as import19 from '@angular/platform-browser/src/dom/events/event_manager';\nimport * as import20 from '@angular/platform-browser/src/dom/shared_styles_host';\nimport * as import21 from '@angular/platform-browser/src/dom/dom_renderer';\nimport * as import22 from '@angular/platform-browser/src/security/dom_sanitization_service';\nimport * as import23 from '@angular/core/src/animation/animation_queue';\nimport * as import24 from '@angular/core/src/linker/view_utils';\nimport * as import25 from '@angular/platform-browser/src/browser/title';\nimport * as import26 from '@angular/http/src/backends/browser_xhr';\nimport * as import27 from '@angular/http/src/base_response_options';\nimport * as import28 from '@angular/http/src/backends/xhr_backend';\nimport * as import29 from '@angular/http/src/base_request_options';\nimport * as import30 from '@angular/forms/src/directives/radio_control_value_accessor';\nimport * as import31 from '@angular/forms/src/form_builder';\nimport * as import32 from 'ionic-angular/components/action-sheet/action-sheet-controller';\nimport * as import33 from 'ionic-angular/components/alert/alert-controller';\nimport * as import34 from 'ionic-angular/util/events';\nimport * as import35 from 'ionic-angular/util/form';\nimport * as import36 from 'ionic-angular/tap-click/haptic';\nimport * as import37 from 'ionic-angular/platform/keyboard';\nimport * as import38 from 'ionic-angular/components/loading/loading-controller';\nimport * as import39 from '@angular/common/src/location/location';\nimport * as import40 from 'ionic-angular/components/modal/modal-controller';\nimport * as import41 from 'ionic-angular/components/picker/picker-controller';\nimport * as import42 from 'ionic-angular/components/popover/popover-controller';\nimport * as import43 from 'ionic-angular/util/system-js-ng-module-loader';\nimport * as import44 from 'ionic-angular/tap-click/tap-click';\nimport * as import45 from 'ionic-angular/components/toast/toast-controller';\nimport * as import46 from 'ionic-angular/transitions/transition-controller';\n" + knownImport + "\n" + knownImport2 + "\nimport * as import50 from '../../node_modules/ionic-angular/components/app/app-root.ngfactory';\nimport * as import51 from '../../node_modules/ionic-angular/components/loading/loading-component.ngfactory';\nimport * as import52 from '../../node_modules/ionic-angular/components/modal/modal-component.ngfactory';\nimport * as import53 from '../../node_modules/ionic-angular/components/picker/picker-component.ngfactory';\nimport * as import54 from '../../node_modules/ionic-angular/components/popover/popover-component.ngfactory';\nimport * as import55 from '../../node_modules/ionic-angular/components/toast/toast-component.ngfactory';\nimport * as import56 from './app.component.ngfactory';\nimport * as import57 from '../pages/home/home.ngfactory';\nimport * as import58 from '@angular/core/src/i18n/tokens';\nimport * as import59 from '@angular/core/src/application_tokens';\nimport * as import60 from '@angular/platform-browser/src/dom/events/dom_events';\nimport * as import61 from '@angular/platform-browser/src/dom/events/key_events';\nimport * as import62 from '@angular/core/src/zone/ng_zone';\nimport * as import63 from '@angular/platform-browser/src/dom/debug/ng_probe';\nimport * as import64 from './app.component';\nimport * as import65 from '@angular/common/src/location/platform_location';\nimport * as import66 from '@angular/common/src/location/location_strategy';\nimport * as import67 from 'ionic-angular/navigation/url-serializer';\nimport * as import68 from 'ionic-angular/navigation/deep-linker';\nimport * as import69 from 'ionic-angular/platform/platform-registry';\nimport * as import70 from 'ionic-angular/platform/platform';\nimport * as import71 from 'ionic-angular/config/config';\nimport * as import72 from 'ionic-angular/config/mode-registry';\nimport * as import73 from '@angular/core/src/console';\nimport * as import74 from '@angular/core/src/error_handler';\nimport * as import75 from '@angular/platform-browser/src/dom/dom_tokens';\nimport * as import76 from '@angular/platform-browser/src/dom/animation_driver';\nimport * as import77 from '@angular/core/src/render/api';\nimport * as import78 from '@angular/core/src/security';\nimport * as import79 from '@angular/core/src/change_detection/differs/iterable_differs';\nimport * as import80 from '@angular/core/src/change_detection/differs/keyvalue_differs';\nimport * as import81 from '@angular/platform-browser/src/browser/meta';\nimport * as import82 from '@angular/http/src/interfaces';\nimport * as import83 from '@angular/http/src/http';\nimport * as import84 from 'ionic-angular/components/app/app-root';\nimport * as import85 from 'ionic-angular/util/module-loader';\nclass AppModuleInjector extends import0.NgModuleInjector {\n    constructor(parent) {\n        super(parent, [\n            " + knownImportUsage + "\n            " + knownImportUsage2 + "\n            import50.IonicAppNgFactory,\n            import51.LoadingCmpNgFactory,\n            import52.ModalCmpNgFactory,\n            import53.PickerCmpNgFactory,\n            import54.PopoverCmpNgFactory,\n            import55.ToastCmpNgFactory,\n            import56.MyAppNgFactory,\n            import57.HomePageNgFactory\n        ], [import50.IonicAppNgFactory]);\n    }\n    get _LOCALE_ID_9() {\n        if ((this.__LOCALE_ID_9 == null)) {\n            (this.__LOCALE_ID_9 = import3._localeFactory(this.parent.get(import58.LOCALE_ID, null)));\n        }\n        return this.__LOCALE_ID_9;\n    }\n    get _NgLocalization_10() {\n        if ((this.__NgLocalization_10 == null)) {\n            (this.__NgLocalization_10 = new import9.NgLocaleLocalization(this._LOCALE_ID_9));\n        }\n        return this.__NgLocalization_10;\n    }\n    get _ApplicationRef_25() {\n        if ((this.__ApplicationRef_25 == null)) {\n            (this.__ApplicationRef_25 = this._ApplicationRef__24);\n        }\n        return this.__ApplicationRef_25;\n    }\n    get _Compiler_26() {\n        if ((this.__Compiler_26 == null)) {\n            (this.__Compiler_26 = new import17.Compiler());\n        }\n        return this.__Compiler_26;\n    }\n    get _APP_ID_27() {\n        if ((this.__APP_ID_27 == null)) {\n            (this.__APP_ID_27 = import59._appIdRandomProviderFactory());\n        }\n        return this.__APP_ID_27;\n    }\n    get _HAMMER_GESTURE_CONFIG_28() {\n        if ((this.__HAMMER_GESTURE_CONFIG_28 == null)) {\n            (this.__HAMMER_GESTURE_CONFIG_28 = new import18.HammerGestureConfig());\n        }\n        return this.__HAMMER_GESTURE_CONFIG_28;\n    }\n    get _EVENT_MANAGER_PLUGINS_29() {\n        if ((this.__EVENT_MANAGER_PLUGINS_29 == null)) {\n            (this.__EVENT_MANAGER_PLUGINS_29 = [\n                new import60.DomEventsPlugin(),\n                new import61.KeyEventsPlugin(),\n                new import18.HammerGesturesPlugin(this._HAMMER_GESTURE_CONFIG_28)\n            ]);\n        }\n        return this.__EVENT_MANAGER_PLUGINS_29;\n    }\n    get _EventManager_30() {\n        if ((this.__EventManager_30 == null)) {\n            (this.__EventManager_30 = new import19.EventManager(this._EVENT_MANAGER_PLUGINS_29, this.parent.get(import62.NgZone)));\n        }\n        return this.__EventManager_30;\n    }\n    get _AnimationDriver_32() {\n        if ((this.__AnimationDriver_32 == null)) {\n            (this.__AnimationDriver_32 = import4._resolveDefaultAnimationDriver());\n        }\n        return this.__AnimationDriver_32;\n    }\n    get _DomRootRenderer_33() {\n        if ((this.__DomRootRenderer_33 == null)) {\n            (this.__DomRootRenderer_33 = new import21.DomRootRenderer_(this._DOCUMENT_13, this._EventManager_30, this._DomSharedStylesHost_31, this._AnimationDriver_32, this._APP_ID_27));\n        }\n        return this.__DomRootRenderer_33;\n    }\n    get _RootRenderer_34() {\n        if ((this.__RootRenderer_34 == null)) {\n            (this.__RootRenderer_34 = import63._createConditionalRootRenderer(this._DomRootRenderer_33, this.parent.get(import63.NgProbeToken, null), this.parent.get(import16.NgProbeToken, null)));\n        }\n        return this.__RootRenderer_34;\n    }\n    get _DomSanitizer_35() {\n        if ((this.__DomSanitizer_35 == null)) {\n            (this.__DomSanitizer_35 = new import22.DomSanitizerImpl());\n        }\n        return this.__DomSanitizer_35;\n    }\n    get _Sanitizer_36() {\n        if ((this.__Sanitizer_36 == null)) {\n            (this.__Sanitizer_36 = this._DomSanitizer_35);\n        }\n        return this.__Sanitizer_36;\n    }\n    get _AnimationQueue_37() {\n        if ((this.__AnimationQueue_37 == null)) {\n            (this.__AnimationQueue_37 = new import23.AnimationQueue(this.parent.get(import62.NgZone)));\n        }\n        return this.__AnimationQueue_37;\n    }\n    get _ViewUtils_38() {\n        if ((this.__ViewUtils_38 == null)) {\n            (this.__ViewUtils_38 = new import24.ViewUtils(this._RootRenderer_34, this._Sanitizer_36, this._AnimationQueue_37));\n        }\n        return this.__ViewUtils_38;\n    }\n    get _IterableDiffers_39() {\n        if ((this.__IterableDiffers_39 == null)) {\n            (this.__IterableDiffers_39 = import3._iterableDiffersFactory());\n        }\n        return this.__IterableDiffers_39;\n    }\n    get _KeyValueDiffers_40() {\n        if ((this.__KeyValueDiffers_40 == null)) {\n            (this.__KeyValueDiffers_40 = import3._keyValueDiffersFactory());\n        }\n        return this.__KeyValueDiffers_40;\n    }\n    get _SharedStylesHost_41() {\n        if ((this.__SharedStylesHost_41 == null)) {\n            (this.__SharedStylesHost_41 = this._DomSharedStylesHost_31);\n        }\n        return this.__SharedStylesHost_41;\n    }\n    get _Meta_42() {\n        if ((this.__Meta_42 == null)) {\n            (this.__Meta_42 = import4.meta());\n        }\n        return this.__Meta_42;\n    }\n    get _Title_43() {\n        if ((this.__Title_43 == null)) {\n            (this.__Title_43 = new import25.Title());\n        }\n        return this.__Title_43;\n    }\n    get _BrowserXhr_44() {\n        if ((this.__BrowserXhr_44 == null)) {\n            (this.__BrowserXhr_44 = new import26.BrowserXhr());\n        }\n        return this.__BrowserXhr_44;\n    }\n    get _ResponseOptions_45() {\n        if ((this.__ResponseOptions_45 == null)) {\n            (this.__ResponseOptions_45 = new import27.BaseResponseOptions());\n        }\n        return this.__ResponseOptions_45;\n    }\n    get _XSRFStrategy_46() {\n        if ((this.__XSRFStrategy_46 == null)) {\n            (this.__XSRFStrategy_46 = import5._createDefaultCookieXSRFStrategy());\n        }\n        return this.__XSRFStrategy_46;\n    }\n    get _XHRBackend_47() {\n        if ((this.__XHRBackend_47 == null)) {\n            (this.__XHRBackend_47 = new import28.XHRBackend(this._BrowserXhr_44, this._ResponseOptions_45, this._XSRFStrategy_46));\n        }\n        return this.__XHRBackend_47;\n    }\n    get _RequestOptions_48() {\n        if ((this.__RequestOptions_48 == null)) {\n            (this.__RequestOptions_48 = new import29.BaseRequestOptions());\n        }\n        return this.__RequestOptions_48;\n    }\n    get _Http_49() {\n        if ((this.__Http_49 == null)) {\n            (this.__Http_49 = import5.httpFactory(this._XHRBackend_47, this._RequestOptions_48));\n        }\n        return this.__Http_49;\n    }\n    get _RadioControlRegistry_50() {\n        if ((this.__RadioControlRegistry_50 == null)) {\n            (this.__RadioControlRegistry_50 = new import30.RadioControlRegistry());\n        }\n        return this.__RadioControlRegistry_50;\n    }\n    get _FormBuilder_51() {\n        if ((this.__FormBuilder_51 == null)) {\n            (this.__FormBuilder_51 = new import31.FormBuilder());\n        }\n        return this.__FormBuilder_51;\n    }\n    get _AppRootToken_52() {\n        if ((this.__AppRootToken_52 == null)) {\n            (this.__AppRootToken_52 = import64.MyApp);\n        }\n        return this.__AppRootToken_52;\n    }\n    get _DeepLinkConfigToken_53() {\n        if ((this.__DeepLinkConfigToken_53 == null)) {\n            (this.__DeepLinkConfigToken_53 = null);\n        }\n        return this.__DeepLinkConfigToken_53;\n    }\n    get _ActionSheetController_54() {\n        if ((this.__ActionSheetController_54 == null)) {\n            (this.__ActionSheetController_54 = new import32.ActionSheetController(this._App_19, this._Config_16));\n        }\n        return this.__ActionSheetController_54;\n    }\n    get _AlertController_55() {\n        if ((this.__AlertController_55 == null)) {\n            (this.__AlertController_55 = new import33.AlertController(this._App_19, this._Config_16));\n        }\n        return this.__AlertController_55;\n    }\n    get _Events_56() {\n        if ((this.__Events_56 == null)) {\n            (this.__Events_56 = new import34.Events());\n        }\n        return this.__Events_56;\n    }\n    get _Form_57() {\n        if ((this.__Form_57 == null)) {\n            (this.__Form_57 = new import35.Form());\n        }\n        return this.__Form_57;\n    }\n    get _Haptic_58() {\n        if ((this.__Haptic_58 == null)) {\n            (this.__Haptic_58 = new import36.Haptic(this._Platform_15));\n        }\n        return this.__Haptic_58;\n    }\n    get _Keyboard_59() {\n        if ((this.__Keyboard_59 == null)) {\n            (this.__Keyboard_59 = new import37.Keyboard(this._Config_16, this._Platform_15, this.parent.get(import62.NgZone), this._DomController_17));\n        }\n        return this.__Keyboard_59;\n    }\n    get _LoadingController_60() {\n        if ((this.__LoadingController_60 == null)) {\n            (this.__LoadingController_60 = new import38.LoadingController(this._App_19, this._Config_16));\n        }\n        return this.__LoadingController_60;\n    }\n    get _LocationStrategy_61() {\n        if ((this.__LocationStrategy_61 == null)) {\n            (this.__LocationStrategy_61 = import8.provideLocationStrategy(this.parent.get(import65.PlatformLocation), this.parent.get(import66.APP_BASE_HREF, null), this._Config_16));\n        }\n        return this.__LocationStrategy_61;\n    }\n    get _Location_62() {\n        if ((this.__Location_62 == null)) {\n            (this.__Location_62 = new import39.Location(this._LocationStrategy_61));\n        }\n        return this.__Location_62;\n    }\n    get _ModalController_63() {\n        if ((this.__ModalController_63 == null)) {\n            (this.__ModalController_63 = new import40.ModalController(this._App_19, this._Config_16));\n        }\n        return this.__ModalController_63;\n    }\n    get _PickerController_64() {\n        if ((this.__PickerController_64 == null)) {\n            (this.__PickerController_64 = new import41.PickerController(this._App_19, this._Config_16));\n        }\n        return this.__PickerController_64;\n    }\n    get _PopoverController_65() {\n        if ((this.__PopoverController_65 == null)) {\n            (this.__PopoverController_65 = new import42.PopoverController(this._App_19, this._Config_16));\n        }\n        return this.__PopoverController_65;\n    }\n    get _SystemJsNgModuleLoader_66() {\n        if ((this.__SystemJsNgModuleLoader_66 == null)) {\n            (this.__SystemJsNgModuleLoader_66 = new import43.SystemJsNgModuleLoader(this._Compiler_26, this.parent.get(import43.SystemJsNgModuleLoaderConfig, null)));\n        }\n        return this.__SystemJsNgModuleLoader_66;\n    }\n    get _TapClick_67() {\n        if ((this.__TapClick_67 == null)) {\n            (this.__TapClick_67 = new import44.TapClick(this._Config_16, this._Platform_15, this._DomController_17, this._App_19, this.parent.get(import62.NgZone), this._GestureController_20));\n        }\n        return this.__TapClick_67;\n    }\n    get _ToastController_68() {\n        if ((this.__ToastController_68 == null)) {\n            (this.__ToastController_68 = new import45.ToastController(this._App_19, this._Config_16));\n        }\n        return this.__ToastController_68;\n    }\n    get _TransitionController_69() {\n        if ((this.__TransitionController_69 == null)) {\n            (this.__TransitionController_69 = new import46.TransitionController(this._Platform_15, this._Config_16));\n        }\n        return this.__TransitionController_69;\n    }\n    get _ModuleLoader_70() {\n        if ((this.__ModuleLoader_70 == null)) {\n            (this.__ModuleLoader_70 = import8.provideModuleLoader(this._DeepLinkConfigToken_53, this._SystemJsNgModuleLoader_66, this));\n        }\n        return this.__ModuleLoader_70;\n    }\n    get _UrlSerializer_71() {\n        if ((this.__UrlSerializer_71 == null)) {\n            (this.__UrlSerializer_71 = import67.setupUrlSerializer(this._DeepLinkConfigToken_53));\n        }\n        return this.__UrlSerializer_71;\n    }\n    get _DeepLinker_72() {\n        if ((this.__DeepLinker_72 == null)) {\n            (this.__DeepLinker_72 = import68.setupDeepLinker(this._App_19, this._UrlSerializer_71, this._Location_62, this._DeepLinkConfigToken_53, this._ModuleLoader_70, this));\n        }\n        return this.__DeepLinker_72;\n    }\n    createInternal() {\n        this._CommonModule_0 = new import2.CommonModule();\n        this._ApplicationModule_1 = new import3.ApplicationModule();\n        this._BrowserModule_2 = new import4.BrowserModule(this.parent.get(import4.BrowserModule, null));\n        this._HttpModule_3 = new import5.HttpModule();\n        this._InternalFormsSharedModule_4 = new import6.InternalFormsSharedModule();\n        this._FormsModule_5 = new import7.FormsModule();\n        this._ReactiveFormsModule_6 = new import7.ReactiveFormsModule();\n        this._IonicModule_7 = new import8.IonicModule();\n        this._AppModule_8 = new import1.AppModule();\n        this._ErrorHandler_11 = import4.errorHandler();\n        this._ConfigToken_12 = null;\n        this._DOCUMENT_13 = import4._document();\n        this._PlatformConfigToken_14 = import69.providePlatformConfigs();\n        this._Platform_15 = import70.setupPlatform(this._DOCUMENT_13, this._PlatformConfigToken_14, this.parent.get(import62.NgZone));\n        this._Config_16 = import71.setupConfig(this._ConfigToken_12, this._Platform_15);\n        this._DomController_17 = new import10.DomController(this._Platform_15);\n        this._MenuController_18 = new import11.MenuController();\n        this._App_19 = new import12.App(this._Config_16, this._Platform_15, this._MenuController_18);\n        this._GestureController_20 = new import13.GestureController(this._App_19);\n        this._APP_INITIALIZER_21 = [\n            import72.registerModeConfigs(this._Config_16),\n            import34.setupProvideEvents(this._Platform_15, this._DomController_17),\n            import44.setupTapClick(this._Config_16, this._Platform_15, this._DomController_17, this._App_19, this.parent.get(import62.NgZone), this._GestureController_20)\n        ];\n        this._ApplicationInitStatus_22 = new import14.ApplicationInitStatus(this._APP_INITIALIZER_21);\n        this._Testability_23 = new import15.Testability(this.parent.get(import62.NgZone));\n        this._ApplicationRef__24 = new import16.ApplicationRef_(this.parent.get(import62.NgZone), this.parent.get(import73.Console), this, this._ErrorHandler_11, this, this._ApplicationInitStatus_22, this.parent.get(import15.TestabilityRegistry, null), this._Testability_23);\n        this._DomSharedStylesHost_31 = new import20.DomSharedStylesHost(this._DOCUMENT_13);\n        return this._AppModule_8;\n    }\n    getInternal(token, notFoundResult) {\n        if ((token === import2.CommonModule)) {\n            return this._CommonModule_0;\n        }\n        if ((token === import3.ApplicationModule)) {\n            return this._ApplicationModule_1;\n        }\n        if ((token === import4.BrowserModule)) {\n            return this._BrowserModule_2;\n        }\n        if ((token === import5.HttpModule)) {\n            return this._HttpModule_3;\n        }\n        if ((token === import6.InternalFormsSharedModule)) {\n            return this._InternalFormsSharedModule_4;\n        }\n        if ((token === import7.FormsModule)) {\n            return this._FormsModule_5;\n        }\n        if ((token === import7.ReactiveFormsModule)) {\n            return this._ReactiveFormsModule_6;\n        }\n        if ((token === import8.IonicModule)) {\n            return this._IonicModule_7;\n        }\n        if ((token === import1.AppModule)) {\n            return this._AppModule_8;\n        }\n        if ((token === import58.LOCALE_ID)) {\n            return this._LOCALE_ID_9;\n        }\n        if ((token === import9.NgLocalization)) {\n            return this._NgLocalization_10;\n        }\n        if ((token === import74.ErrorHandler)) {\n            return this._ErrorHandler_11;\n        }\n        if ((token === import71.ConfigToken)) {\n            return this._ConfigToken_12;\n        }\n        if ((token === import75.DOCUMENT)) {\n            return this._DOCUMENT_13;\n        }\n        if ((token === import69.PlatformConfigToken)) {\n            return this._PlatformConfigToken_14;\n        }\n        if ((token === import70.Platform)) {\n            return this._Platform_15;\n        }\n        if ((token === import71.Config)) {\n            return this._Config_16;\n        }\n        if ((token === import10.DomController)) {\n            return this._DomController_17;\n        }\n        if ((token === import11.MenuController)) {\n            return this._MenuController_18;\n        }\n        if ((token === import12.App)) {\n            return this._App_19;\n        }\n        if ((token === import13.GestureController)) {\n            return this._GestureController_20;\n        }\n        if ((token === import14.APP_INITIALIZER)) {\n            return this._APP_INITIALIZER_21;\n        }\n        if ((token === import14.ApplicationInitStatus)) {\n            return this._ApplicationInitStatus_22;\n        }\n        if ((token === import15.Testability)) {\n            return this._Testability_23;\n        }\n        if ((token === import16.ApplicationRef_)) {\n            return this._ApplicationRef__24;\n        }\n        if ((token === import16.ApplicationRef)) {\n            return this._ApplicationRef_25;\n        }\n        if ((token === import17.Compiler)) {\n            return this._Compiler_26;\n        }\n        if ((token === import59.APP_ID)) {\n            return this._APP_ID_27;\n        }\n        if ((token === import18.HAMMER_GESTURE_CONFIG)) {\n            return this._HAMMER_GESTURE_CONFIG_28;\n        }\n        if ((token === import19.EVENT_MANAGER_PLUGINS)) {\n            return this._EVENT_MANAGER_PLUGINS_29;\n        }\n        if ((token === import19.EventManager)) {\n            return this._EventManager_30;\n        }\n        if ((token === import20.DomSharedStylesHost)) {\n            return this._DomSharedStylesHost_31;\n        }\n        if ((token === import76.AnimationDriver)) {\n            return this._AnimationDriver_32;\n        }\n        if ((token === import21.DomRootRenderer)) {\n            return this._DomRootRenderer_33;\n        }\n        if ((token === import77.RootRenderer)) {\n            return this._RootRenderer_34;\n        }\n        if ((token === import22.DomSanitizer)) {\n            return this._DomSanitizer_35;\n        }\n        if ((token === import78.Sanitizer)) {\n            return this._Sanitizer_36;\n        }\n        if ((token === import23.AnimationQueue)) {\n            return this._AnimationQueue_37;\n        }\n        if ((token === import24.ViewUtils)) {\n            return this._ViewUtils_38;\n        }\n        if ((token === import79.IterableDiffers)) {\n            return this._IterableDiffers_39;\n        }\n        if ((token === import80.KeyValueDiffers)) {\n            return this._KeyValueDiffers_40;\n        }\n        if ((token === import20.SharedStylesHost)) {\n            return this._SharedStylesHost_41;\n        }\n        if ((token === import81.Meta)) {\n            return this._Meta_42;\n        }\n        if ((token === import25.Title)) {\n            return this._Title_43;\n        }\n        if ((token === import26.BrowserXhr)) {\n            return this._BrowserXhr_44;\n        }\n        if ((token === import27.ResponseOptions)) {\n            return this._ResponseOptions_45;\n        }\n        if ((token === import82.XSRFStrategy)) {\n            return this._XSRFStrategy_46;\n        }\n        if ((token === import28.XHRBackend)) {\n            return this._XHRBackend_47;\n        }\n        if ((token === import29.RequestOptions)) {\n            return this._RequestOptions_48;\n        }\n        if ((token === import83.Http)) {\n            return this._Http_49;\n        }\n        if ((token === import30.RadioControlRegistry)) {\n            return this._RadioControlRegistry_50;\n        }\n        if ((token === import31.FormBuilder)) {\n            return this._FormBuilder_51;\n        }\n        if ((token === import84.AppRootToken)) {\n            return this._AppRootToken_52;\n        }\n        if ((token === import67.DeepLinkConfigToken)) {\n            return this._DeepLinkConfigToken_53;\n        }\n        if ((token === import32.ActionSheetController)) {\n            return this._ActionSheetController_54;\n        }\n        if ((token === import33.AlertController)) {\n            return this._AlertController_55;\n        }\n        if ((token === import34.Events)) {\n            return this._Events_56;\n        }\n        if ((token === import35.Form)) {\n            return this._Form_57;\n        }\n        if ((token === import36.Haptic)) {\n            return this._Haptic_58;\n        }\n        if ((token === import37.Keyboard)) {\n            return this._Keyboard_59;\n        }\n        if ((token === import38.LoadingController)) {\n            return this._LoadingController_60;\n        }\n        if ((token === import66.LocationStrategy)) {\n            return this._LocationStrategy_61;\n        }\n        if ((token === import39.Location)) {\n            return this._Location_62;\n        }\n        if ((token === import40.ModalController)) {\n            return this._ModalController_63;\n        }\n        if ((token === import41.PickerController)) {\n            return this._PickerController_64;\n        }\n        if ((token === import42.PopoverController)) {\n            return this._PopoverController_65;\n        }\n        if ((token === import43.SystemJsNgModuleLoader)) {\n            return this._SystemJsNgModuleLoader_66;\n        }\n        if ((token === import44.TapClick)) {\n            return this._TapClick_67;\n        }\n        if ((token === import45.ToastController)) {\n            return this._ToastController_68;\n        }\n        if ((token === import46.TransitionController)) {\n            return this._TransitionController_69;\n        }\n        if ((token === import85.ModuleLoader)) {\n            return this._ModuleLoader_70;\n        }\n        if ((token === import67.UrlSerializer)) {\n            return this._UrlSerializer_71;\n        }\n        if ((token === import68.DeepLinker)) {\n            return this._DeepLinker_72;\n        }\n        return notFoundResult;\n    }\n    destroyInternal() {\n        this._ApplicationRef__24.ngOnDestroy();\n        this._DomSharedStylesHost_31.ngOnDestroy();\n    }\n}\nexport const AppModuleNgFactory = new import0.NgModuleFactory(AppModuleInjector, import1.AppModule);\n//# sourceMappingURL=app.module.ngfactory.js.map\n      ";
            var appModuleNgFactoryPath = path_1.join(srcDir, 'app', 'app.module.ngfactory.js');
            var componentFactoryPath = path_1.join(componentDir, 'action-sheet', 'action-sheet-component.ngfactory.js');
            var componentFactoryPath2 = path_1.join(componentDir, 'alert', 'alert-component.ngfactory.js');
            // act
            var updatedContent = treeshake.purgeComponentNgFactoryImportAndUsage(appModuleNgFactoryPath, knownContent, componentFactoryPath);
            var updatedContentAgain = treeshake.purgeComponentNgFactoryImportAndUsage(appModuleNgFactoryPath, updatedContent, componentFactoryPath2);
            // assert
            expect(updatedContentAgain).not.toEqual(knownContent);
            var knownImportOneRegex = treeshake.generateWildCardImportRegex('../../node_modules/ionic-angular/components/action-sheet/action-sheet-component.ngfactory');
            var knownImportTwoRegex = treeshake.generateWildCardImportRegex('../../node_modules/ionic-angular/components/alert/alert-component.ngfactory');
            var knownImportOneResults = knownImportOneRegex.exec(updatedContentAgain);
            var knownImportTwoResults = knownImportTwoRegex.exec(updatedContentAgain);
            var knownNamedImportOne = knownImportOneResults[1].trim();
            var knownNamedImportTwo = knownImportTwoResults[1].trim();
            expect(updatedContentAgain.indexOf("/*" + knownImportOneResults[0] + "*/")).toBeGreaterThanOrEqual(0);
            expect(updatedContentAgain.indexOf("/*" + knownImportTwoResults[0] + "*/")).toBeGreaterThanOrEqual(0);
            var removeFromConstructorRegexOne = treeshake.generateRemoveComponentFromConstructorRegex(knownNamedImportOne);
            var removeFromConstructorRegexTwo = treeshake.generateRemoveComponentFromConstructorRegex(knownNamedImportTwo);
            var removeFromConstructorOneResults = removeFromConstructorRegexOne.exec(updatedContentAgain);
            var removeFromConstructorTwoResults = removeFromConstructorRegexTwo.exec(updatedContentAgain);
            expect(updatedContentAgain.indexOf("/*" + removeFromConstructorOneResults[0] + "*/")).toBeGreaterThanOrEqual(0);
            expect(updatedContentAgain.indexOf("/*" + removeFromConstructorTwoResults[0] + "*/")).toBeGreaterThanOrEqual(0);
        });
    });
    describe('purgeProviderControllerImportAndUsage', function () {
        it('should purge the controller provider content', function () {
            // arrange
            var ifStatementOne = "\nif ((token === import32.ActionSheetController)) {\n    return this._ActionSheetController_54;\n}\n      ";
            var ifStatementTwo = "\nif ((token === import33.AlertController)) {\n    return this._AlertController_55;\n}\n      ";
            var getterOne = "\nget _ActionSheetController_54() {\n    if ((this.__ActionSheetController_54 == null)) {\n        (this.__ActionSheetController_54 = new import32.ActionSheetController(this._App_19, this._Config_16));\n    }\n    return this.__ActionSheetController_54;\n}\n      ";
            var getterTwo = "\nget _AlertController_55() {\n    if ((this.__AlertController_55 == null)) {\n        (this.__AlertController_55 = new import33.AlertController(this._App_19, this._Config_16));\n    }\n    return this.__AlertController_55;\n}\n      ";
            var knownContent = "\n        /**\n * @fileoverview This file is generated by the Angular template compiler.\n * Do not edit.\n * @suppress {suspiciousCode,uselessCode,missingProperties}\n */\n/* tslint:disable */\nimport * as import0 from '@angular/core/src/linker/ng_module_factory';\nimport * as import1 from './app.module';\nimport * as import2 from '@angular/common/src/common_module';\nimport * as import3 from '@angular/core/src/application_module';\nimport * as import4 from '@angular/platform-browser/src/browser';\nimport * as import5 from '@angular/http/src/http_module';\nimport * as import6 from '@angular/forms/src/directives';\nimport * as import7 from '@angular/forms/src/form_providers';\nimport * as import8 from 'ionic-angular/index';\nimport * as import9 from '@angular/common/src/localization';\nimport * as import10 from 'ionic-angular/platform/dom-controller';\nimport * as import11 from 'ionic-angular/components/menu/menu-controller';\nimport * as import12 from 'ionic-angular/components/app/app';\nimport * as import13 from 'ionic-angular/gestures/gesture-controller';\nimport * as import14 from '@angular/core/src/application_init';\nimport * as import15 from '@angular/core/src/testability/testability';\nimport * as import16 from '@angular/core/src/application_ref';\nimport * as import17 from '@angular/core/src/linker/compiler';\nimport * as import18 from '@angular/platform-browser/src/dom/events/hammer_gestures';\nimport * as import19 from '@angular/platform-browser/src/dom/events/event_manager';\nimport * as import20 from '@angular/platform-browser/src/dom/shared_styles_host';\nimport * as import21 from '@angular/platform-browser/src/dom/dom_renderer';\nimport * as import22 from '@angular/platform-browser/src/security/dom_sanitization_service';\nimport * as import23 from '@angular/core/src/animation/animation_queue';\nimport * as import24 from '@angular/core/src/linker/view_utils';\nimport * as import25 from '@angular/platform-browser/src/browser/title';\nimport * as import26 from '@angular/http/src/backends/browser_xhr';\nimport * as import27 from '@angular/http/src/base_response_options';\nimport * as import28 from '@angular/http/src/backends/xhr_backend';\nimport * as import29 from '@angular/http/src/base_request_options';\nimport * as import30 from '@angular/forms/src/directives/radio_control_value_accessor';\nimport * as import31 from '@angular/forms/src/form_builder';\nimport * as import32 from 'ionic-angular/components/action-sheet/action-sheet-controller';\nimport * as import33 from 'ionic-angular/components/alert/alert-controller';\nimport * as import34 from 'ionic-angular/util/events';\nimport * as import35 from 'ionic-angular/util/form';\nimport * as import36 from 'ionic-angular/tap-click/haptic';\nimport * as import37 from 'ionic-angular/platform/keyboard';\nimport * as import38 from 'ionic-angular/components/loading/loading-controller';\nimport * as import39 from '@angular/common/src/location/location';\nimport * as import40 from 'ionic-angular/components/modal/modal-controller';\nimport * as import41 from 'ionic-angular/components/picker/picker-controller';\nimport * as import42 from 'ionic-angular/components/popover/popover-controller';\nimport * as import43 from 'ionic-angular/util/system-js-ng-module-loader';\nimport * as import44 from 'ionic-angular/tap-click/tap-click';\nimport * as import45 from 'ionic-angular/components/toast/toast-controller';\nimport * as import46 from 'ionic-angular/transitions/transition-controller';\nimport * as import48 from '../../node_modules/ionic-angular/components/action-sheet/action-sheet-component.ngfactory';\nimport * as import49 from '../../node_modules/ionic-angular/components/alert/alert-component.ngfactory';\nimport * as import50 from '../../node_modules/ionic-angular/components/app/app-root.ngfactory';\nimport * as import51 from '../../node_modules/ionic-angular/components/loading/loading-component.ngfactory';\nimport * as import52 from '../../node_modules/ionic-angular/components/modal/modal-component.ngfactory';\nimport * as import53 from '../../node_modules/ionic-angular/components/picker/picker-component.ngfactory';\nimport * as import54 from '../../node_modules/ionic-angular/components/popover/popover-component.ngfactory';\nimport * as import55 from '../../node_modules/ionic-angular/components/toast/toast-component.ngfactory';\nimport * as import56 from './app.component.ngfactory';\nimport * as import57 from '../pages/home/home.ngfactory';\nimport * as import58 from '@angular/core/src/i18n/tokens';\nimport * as import59 from '@angular/core/src/application_tokens';\nimport * as import60 from '@angular/platform-browser/src/dom/events/dom_events';\nimport * as import61 from '@angular/platform-browser/src/dom/events/key_events';\nimport * as import62 from '@angular/core/src/zone/ng_zone';\nimport * as import63 from '@angular/platform-browser/src/dom/debug/ng_probe';\nimport * as import64 from './app.component';\nimport * as import65 from '@angular/common/src/location/platform_location';\nimport * as import66 from '@angular/common/src/location/location_strategy';\nimport * as import67 from 'ionic-angular/navigation/url-serializer';\nimport * as import68 from 'ionic-angular/navigation/deep-linker';\nimport * as import69 from 'ionic-angular/platform/platform-registry';\nimport * as import70 from 'ionic-angular/platform/platform';\nimport * as import71 from 'ionic-angular/config/config';\nimport * as import72 from 'ionic-angular/config/mode-registry';\nimport * as import73 from '@angular/core/src/console';\nimport * as import74 from '@angular/core/src/error_handler';\nimport * as import75 from '@angular/platform-browser/src/dom/dom_tokens';\nimport * as import76 from '@angular/platform-browser/src/dom/animation_driver';\nimport * as import77 from '@angular/core/src/render/api';\nimport * as import78 from '@angular/core/src/security';\nimport * as import79 from '@angular/core/src/change_detection/differs/iterable_differs';\nimport * as import80 from '@angular/core/src/change_detection/differs/keyvalue_differs';\nimport * as import81 from '@angular/platform-browser/src/browser/meta';\nimport * as import82 from '@angular/http/src/interfaces';\nimport * as import83 from '@angular/http/src/http';\nimport * as import84 from 'ionic-angular/components/app/app-root';\nimport * as import85 from 'ionic-angular/util/module-loader';\nclass AppModuleInjector extends import0.NgModuleInjector {\n    constructor(parent) {\n        super(parent, [\n            import48.ActionSheetCmpNgFactory,\n            import49.AlertCmpNgFactory,\n            import50.IonicAppNgFactory,\n            import51.LoadingCmpNgFactory,\n            import52.ModalCmpNgFactory,\n            import53.PickerCmpNgFactory,\n            import54.PopoverCmpNgFactory,\n            import55.ToastCmpNgFactory,\n            import56.MyAppNgFactory,\n            import57.HomePageNgFactory\n        ], [import50.IonicAppNgFactory]);\n    }\n    get _LOCALE_ID_9() {\n        if ((this.__LOCALE_ID_9 == null)) {\n            (this.__LOCALE_ID_9 = import3._localeFactory(this.parent.get(import58.LOCALE_ID, null)));\n        }\n        return this.__LOCALE_ID_9;\n    }\n    get _NgLocalization_10() {\n        if ((this.__NgLocalization_10 == null)) {\n            (this.__NgLocalization_10 = new import9.NgLocaleLocalization(this._LOCALE_ID_9));\n        }\n        return this.__NgLocalization_10;\n    }\n    get _ApplicationRef_25() {\n        if ((this.__ApplicationRef_25 == null)) {\n            (this.__ApplicationRef_25 = this._ApplicationRef__24);\n        }\n        return this.__ApplicationRef_25;\n    }\n    get _Compiler_26() {\n        if ((this.__Compiler_26 == null)) {\n            (this.__Compiler_26 = new import17.Compiler());\n        }\n        return this.__Compiler_26;\n    }\n    get _APP_ID_27() {\n        if ((this.__APP_ID_27 == null)) {\n            (this.__APP_ID_27 = import59._appIdRandomProviderFactory());\n        }\n        return this.__APP_ID_27;\n    }\n    get _HAMMER_GESTURE_CONFIG_28() {\n        if ((this.__HAMMER_GESTURE_CONFIG_28 == null)) {\n            (this.__HAMMER_GESTURE_CONFIG_28 = new import18.HammerGestureConfig());\n        }\n        return this.__HAMMER_GESTURE_CONFIG_28;\n    }\n    get _EVENT_MANAGER_PLUGINS_29() {\n        if ((this.__EVENT_MANAGER_PLUGINS_29 == null)) {\n            (this.__EVENT_MANAGER_PLUGINS_29 = [\n                new import60.DomEventsPlugin(),\n                new import61.KeyEventsPlugin(),\n                new import18.HammerGesturesPlugin(this._HAMMER_GESTURE_CONFIG_28)\n            ]);\n        }\n        return this.__EVENT_MANAGER_PLUGINS_29;\n    }\n    get _EventManager_30() {\n        if ((this.__EventManager_30 == null)) {\n            (this.__EventManager_30 = new import19.EventManager(this._EVENT_MANAGER_PLUGINS_29, this.parent.get(import62.NgZone)));\n        }\n        return this.__EventManager_30;\n    }\n    get _AnimationDriver_32() {\n        if ((this.__AnimationDriver_32 == null)) {\n            (this.__AnimationDriver_32 = import4._resolveDefaultAnimationDriver());\n        }\n        return this.__AnimationDriver_32;\n    }\n    get _DomRootRenderer_33() {\n        if ((this.__DomRootRenderer_33 == null)) {\n            (this.__DomRootRenderer_33 = new import21.DomRootRenderer_(this._DOCUMENT_13, this._EventManager_30, this._DomSharedStylesHost_31, this._AnimationDriver_32, this._APP_ID_27));\n        }\n        return this.__DomRootRenderer_33;\n    }\n    get _RootRenderer_34() {\n        if ((this.__RootRenderer_34 == null)) {\n            (this.__RootRenderer_34 = import63._createConditionalRootRenderer(this._DomRootRenderer_33, this.parent.get(import63.NgProbeToken, null), this.parent.get(import16.NgProbeToken, null)));\n        }\n        return this.__RootRenderer_34;\n    }\n    get _DomSanitizer_35() {\n        if ((this.__DomSanitizer_35 == null)) {\n            (this.__DomSanitizer_35 = new import22.DomSanitizerImpl());\n        }\n        return this.__DomSanitizer_35;\n    }\n    get _Sanitizer_36() {\n        if ((this.__Sanitizer_36 == null)) {\n            (this.__Sanitizer_36 = this._DomSanitizer_35);\n        }\n        return this.__Sanitizer_36;\n    }\n    get _AnimationQueue_37() {\n        if ((this.__AnimationQueue_37 == null)) {\n            (this.__AnimationQueue_37 = new import23.AnimationQueue(this.parent.get(import62.NgZone)));\n        }\n        return this.__AnimationQueue_37;\n    }\n    get _ViewUtils_38() {\n        if ((this.__ViewUtils_38 == null)) {\n            (this.__ViewUtils_38 = new import24.ViewUtils(this._RootRenderer_34, this._Sanitizer_36, this._AnimationQueue_37));\n        }\n        return this.__ViewUtils_38;\n    }\n    get _IterableDiffers_39() {\n        if ((this.__IterableDiffers_39 == null)) {\n            (this.__IterableDiffers_39 = import3._iterableDiffersFactory());\n        }\n        return this.__IterableDiffers_39;\n    }\n    get _KeyValueDiffers_40() {\n        if ((this.__KeyValueDiffers_40 == null)) {\n            (this.__KeyValueDiffers_40 = import3._keyValueDiffersFactory());\n        }\n        return this.__KeyValueDiffers_40;\n    }\n    get _SharedStylesHost_41() {\n        if ((this.__SharedStylesHost_41 == null)) {\n            (this.__SharedStylesHost_41 = this._DomSharedStylesHost_31);\n        }\n        return this.__SharedStylesHost_41;\n    }\n    get _Meta_42() {\n        if ((this.__Meta_42 == null)) {\n            (this.__Meta_42 = import4.meta());\n        }\n        return this.__Meta_42;\n    }\n    get _Title_43() {\n        if ((this.__Title_43 == null)) {\n            (this.__Title_43 = new import25.Title());\n        }\n        return this.__Title_43;\n    }\n    get _BrowserXhr_44() {\n        if ((this.__BrowserXhr_44 == null)) {\n            (this.__BrowserXhr_44 = new import26.BrowserXhr());\n        }\n        return this.__BrowserXhr_44;\n    }\n    get _ResponseOptions_45() {\n        if ((this.__ResponseOptions_45 == null)) {\n            (this.__ResponseOptions_45 = new import27.BaseResponseOptions());\n        }\n        return this.__ResponseOptions_45;\n    }\n    get _XSRFStrategy_46() {\n        if ((this.__XSRFStrategy_46 == null)) {\n            (this.__XSRFStrategy_46 = import5._createDefaultCookieXSRFStrategy());\n        }\n        return this.__XSRFStrategy_46;\n    }\n    get _XHRBackend_47() {\n        if ((this.__XHRBackend_47 == null)) {\n            (this.__XHRBackend_47 = new import28.XHRBackend(this._BrowserXhr_44, this._ResponseOptions_45, this._XSRFStrategy_46));\n        }\n        return this.__XHRBackend_47;\n    }\n    get _RequestOptions_48() {\n        if ((this.__RequestOptions_48 == null)) {\n            (this.__RequestOptions_48 = new import29.BaseRequestOptions());\n        }\n        return this.__RequestOptions_48;\n    }\n    get _Http_49() {\n        if ((this.__Http_49 == null)) {\n            (this.__Http_49 = import5.httpFactory(this._XHRBackend_47, this._RequestOptions_48));\n        }\n        return this.__Http_49;\n    }\n    get _RadioControlRegistry_50() {\n        if ((this.__RadioControlRegistry_50 == null)) {\n            (this.__RadioControlRegistry_50 = new import30.RadioControlRegistry());\n        }\n        return this.__RadioControlRegistry_50;\n    }\n    get _FormBuilder_51() {\n        if ((this.__FormBuilder_51 == null)) {\n            (this.__FormBuilder_51 = new import31.FormBuilder());\n        }\n        return this.__FormBuilder_51;\n    }\n    get _AppRootToken_52() {\n        if ((this.__AppRootToken_52 == null)) {\n            (this.__AppRootToken_52 = import64.MyApp);\n        }\n        return this.__AppRootToken_52;\n    }\n    get _DeepLinkConfigToken_53() {\n        if ((this.__DeepLinkConfigToken_53 == null)) {\n            (this.__DeepLinkConfigToken_53 = null);\n        }\n        return this.__DeepLinkConfigToken_53;\n    }\n    " + getterOne + "\n    " + getterTwo + "\n    get _Events_56() {\n        if ((this.__Events_56 == null)) {\n            (this.__Events_56 = new import34.Events());\n        }\n        return this.__Events_56;\n    }\n    get _Form_57() {\n        if ((this.__Form_57 == null)) {\n            (this.__Form_57 = new import35.Form());\n        }\n        return this.__Form_57;\n    }\n    get _Haptic_58() {\n        if ((this.__Haptic_58 == null)) {\n            (this.__Haptic_58 = new import36.Haptic(this._Platform_15));\n        }\n        return this.__Haptic_58;\n    }\n    get _Keyboard_59() {\n        if ((this.__Keyboard_59 == null)) {\n            (this.__Keyboard_59 = new import37.Keyboard(this._Config_16, this._Platform_15, this.parent.get(import62.NgZone), this._DomController_17));\n        }\n        return this.__Keyboard_59;\n    }\n    get _LoadingController_60() {\n        if ((this.__LoadingController_60 == null)) {\n            (this.__LoadingController_60 = new import38.LoadingController(this._App_19, this._Config_16));\n        }\n        return this.__LoadingController_60;\n    }\n    get _LocationStrategy_61() {\n        if ((this.__LocationStrategy_61 == null)) {\n            (this.__LocationStrategy_61 = import8.provideLocationStrategy(this.parent.get(import65.PlatformLocation), this.parent.get(import66.APP_BASE_HREF, null), this._Config_16));\n        }\n        return this.__LocationStrategy_61;\n    }\n    get _Location_62() {\n        if ((this.__Location_62 == null)) {\n            (this.__Location_62 = new import39.Location(this._LocationStrategy_61));\n        }\n        return this.__Location_62;\n    }\n    get _ModalController_63() {\n        if ((this.__ModalController_63 == null)) {\n            (this.__ModalController_63 = new import40.ModalController(this._App_19, this._Config_16));\n        }\n        return this.__ModalController_63;\n    }\n    get _PickerController_64() {\n        if ((this.__PickerController_64 == null)) {\n            (this.__PickerController_64 = new import41.PickerController(this._App_19, this._Config_16));\n        }\n        return this.__PickerController_64;\n    }\n    get _PopoverController_65() {\n        if ((this.__PopoverController_65 == null)) {\n            (this.__PopoverController_65 = new import42.PopoverController(this._App_19, this._Config_16));\n        }\n        return this.__PopoverController_65;\n    }\n    get _SystemJsNgModuleLoader_66() {\n        if ((this.__SystemJsNgModuleLoader_66 == null)) {\n            (this.__SystemJsNgModuleLoader_66 = new import43.SystemJsNgModuleLoader(this._Compiler_26, this.parent.get(import43.SystemJsNgModuleLoaderConfig, null)));\n        }\n        return this.__SystemJsNgModuleLoader_66;\n    }\n    get _TapClick_67() {\n        if ((this.__TapClick_67 == null)) {\n            (this.__TapClick_67 = new import44.TapClick(this._Config_16, this._Platform_15, this._DomController_17, this._App_19, this.parent.get(import62.NgZone), this._GestureController_20));\n        }\n        return this.__TapClick_67;\n    }\n    get _ToastController_68() {\n        if ((this.__ToastController_68 == null)) {\n            (this.__ToastController_68 = new import45.ToastController(this._App_19, this._Config_16));\n        }\n        return this.__ToastController_68;\n    }\n    get _TransitionController_69() {\n        if ((this.__TransitionController_69 == null)) {\n            (this.__TransitionController_69 = new import46.TransitionController(this._Platform_15, this._Config_16));\n        }\n        return this.__TransitionController_69;\n    }\n    get _ModuleLoader_70() {\n        if ((this.__ModuleLoader_70 == null)) {\n            (this.__ModuleLoader_70 = import8.provideModuleLoader(this._DeepLinkConfigToken_53, this._SystemJsNgModuleLoader_66, this));\n        }\n        return this.__ModuleLoader_70;\n    }\n    get _UrlSerializer_71() {\n        if ((this.__UrlSerializer_71 == null)) {\n            (this.__UrlSerializer_71 = import67.setupUrlSerializer(this._DeepLinkConfigToken_53));\n        }\n        return this.__UrlSerializer_71;\n    }\n    get _DeepLinker_72() {\n        if ((this.__DeepLinker_72 == null)) {\n            (this.__DeepLinker_72 = import68.setupDeepLinker(this._App_19, this._UrlSerializer_71, this._Location_62, this._DeepLinkConfigToken_53, this._ModuleLoader_70, this));\n        }\n        return this.__DeepLinker_72;\n    }\n    createInternal() {\n        this._CommonModule_0 = new import2.CommonModule();\n        this._ApplicationModule_1 = new import3.ApplicationModule();\n        this._BrowserModule_2 = new import4.BrowserModule(this.parent.get(import4.BrowserModule, null));\n        this._HttpModule_3 = new import5.HttpModule();\n        this._InternalFormsSharedModule_4 = new import6.InternalFormsSharedModule();\n        this._FormsModule_5 = new import7.FormsModule();\n        this._ReactiveFormsModule_6 = new import7.ReactiveFormsModule();\n        this._IonicModule_7 = new import8.IonicModule();\n        this._AppModule_8 = new import1.AppModule();\n        this._ErrorHandler_11 = import4.errorHandler();\n        this._ConfigToken_12 = null;\n        this._DOCUMENT_13 = import4._document();\n        this._PlatformConfigToken_14 = import69.providePlatformConfigs();\n        this._Platform_15 = import70.setupPlatform(this._DOCUMENT_13, this._PlatformConfigToken_14, this.parent.get(import62.NgZone));\n        this._Config_16 = import71.setupConfig(this._ConfigToken_12, this._Platform_15);\n        this._DomController_17 = new import10.DomController(this._Platform_15);\n        this._MenuController_18 = new import11.MenuController();\n        this._App_19 = new import12.App(this._Config_16, this._Platform_15, this._MenuController_18);\n        this._GestureController_20 = new import13.GestureController(this._App_19);\n        this._APP_INITIALIZER_21 = [\n            import72.registerModeConfigs(this._Config_16),\n            import34.setupProvideEvents(this._Platform_15, this._DomController_17),\n            import44.setupTapClick(this._Config_16, this._Platform_15, this._DomController_17, this._App_19, this.parent.get(import62.NgZone), this._GestureController_20)\n        ];\n        this._ApplicationInitStatus_22 = new import14.ApplicationInitStatus(this._APP_INITIALIZER_21);\n        this._Testability_23 = new import15.Testability(this.parent.get(import62.NgZone));\n        this._ApplicationRef__24 = new import16.ApplicationRef_(this.parent.get(import62.NgZone), this.parent.get(import73.Console), this, this._ErrorHandler_11, this, this._ApplicationInitStatus_22, this.parent.get(import15.TestabilityRegistry, null), this._Testability_23);\n        this._DomSharedStylesHost_31 = new import20.DomSharedStylesHost(this._DOCUMENT_13);\n        return this._AppModule_8;\n    }\n    getInternal(token, notFoundResult) {\n        if ((token === import2.CommonModule)) {\n            return this._CommonModule_0;\n        }\n        if ((token === import3.ApplicationModule)) {\n            return this._ApplicationModule_1;\n        }\n        if ((token === import4.BrowserModule)) {\n            return this._BrowserModule_2;\n        }\n        if ((token === import5.HttpModule)) {\n            return this._HttpModule_3;\n        }\n        if ((token === import6.InternalFormsSharedModule)) {\n            return this._InternalFormsSharedModule_4;\n        }\n        if ((token === import7.FormsModule)) {\n            return this._FormsModule_5;\n        }\n        if ((token === import7.ReactiveFormsModule)) {\n            return this._ReactiveFormsModule_6;\n        }\n        if ((token === import8.IonicModule)) {\n            return this._IonicModule_7;\n        }\n        if ((token === import1.AppModule)) {\n            return this._AppModule_8;\n        }\n        if ((token === import58.LOCALE_ID)) {\n            return this._LOCALE_ID_9;\n        }\n        if ((token === import9.NgLocalization)) {\n            return this._NgLocalization_10;\n        }\n        if ((token === import74.ErrorHandler)) {\n            return this._ErrorHandler_11;\n        }\n        if ((token === import71.ConfigToken)) {\n            return this._ConfigToken_12;\n        }\n        if ((token === import75.DOCUMENT)) {\n            return this._DOCUMENT_13;\n        }\n        if ((token === import69.PlatformConfigToken)) {\n            return this._PlatformConfigToken_14;\n        }\n        if ((token === import70.Platform)) {\n            return this._Platform_15;\n        }\n        if ((token === import71.Config)) {\n            return this._Config_16;\n        }\n        if ((token === import10.DomController)) {\n            return this._DomController_17;\n        }\n        if ((token === import11.MenuController)) {\n            return this._MenuController_18;\n        }\n        if ((token === import12.App)) {\n            return this._App_19;\n        }\n        if ((token === import13.GestureController)) {\n            return this._GestureController_20;\n        }\n        if ((token === import14.APP_INITIALIZER)) {\n            return this._APP_INITIALIZER_21;\n        }\n        if ((token === import14.ApplicationInitStatus)) {\n            return this._ApplicationInitStatus_22;\n        }\n        if ((token === import15.Testability)) {\n            return this._Testability_23;\n        }\n        if ((token === import16.ApplicationRef_)) {\n            return this._ApplicationRef__24;\n        }\n        if ((token === import16.ApplicationRef)) {\n            return this._ApplicationRef_25;\n        }\n        if ((token === import17.Compiler)) {\n            return this._Compiler_26;\n        }\n        if ((token === import59.APP_ID)) {\n            return this._APP_ID_27;\n        }\n        if ((token === import18.HAMMER_GESTURE_CONFIG)) {\n            return this._HAMMER_GESTURE_CONFIG_28;\n        }\n        if ((token === import19.EVENT_MANAGER_PLUGINS)) {\n            return this._EVENT_MANAGER_PLUGINS_29;\n        }\n        if ((token === import19.EventManager)) {\n            return this._EventManager_30;\n        }\n        if ((token === import20.DomSharedStylesHost)) {\n            return this._DomSharedStylesHost_31;\n        }\n        if ((token === import76.AnimationDriver)) {\n            return this._AnimationDriver_32;\n        }\n        if ((token === import21.DomRootRenderer)) {\n            return this._DomRootRenderer_33;\n        }\n        if ((token === import77.RootRenderer)) {\n            return this._RootRenderer_34;\n        }\n        if ((token === import22.DomSanitizer)) {\n            return this._DomSanitizer_35;\n        }\n        if ((token === import78.Sanitizer)) {\n            return this._Sanitizer_36;\n        }\n        if ((token === import23.AnimationQueue)) {\n            return this._AnimationQueue_37;\n        }\n        if ((token === import24.ViewUtils)) {\n            return this._ViewUtils_38;\n        }\n        if ((token === import79.IterableDiffers)) {\n            return this._IterableDiffers_39;\n        }\n        if ((token === import80.KeyValueDiffers)) {\n            return this._KeyValueDiffers_40;\n        }\n        if ((token === import20.SharedStylesHost)) {\n            return this._SharedStylesHost_41;\n        }\n        if ((token === import81.Meta)) {\n            return this._Meta_42;\n        }\n        if ((token === import25.Title)) {\n            return this._Title_43;\n        }\n        if ((token === import26.BrowserXhr)) {\n            return this._BrowserXhr_44;\n        }\n        if ((token === import27.ResponseOptions)) {\n            return this._ResponseOptions_45;\n        }\n        if ((token === import82.XSRFStrategy)) {\n            return this._XSRFStrategy_46;\n        }\n        if ((token === import28.XHRBackend)) {\n            return this._XHRBackend_47;\n        }\n        if ((token === import29.RequestOptions)) {\n            return this._RequestOptions_48;\n        }\n        if ((token === import83.Http)) {\n            return this._Http_49;\n        }\n        if ((token === import30.RadioControlRegistry)) {\n            return this._RadioControlRegistry_50;\n        }\n        if ((token === import31.FormBuilder)) {\n            return this._FormBuilder_51;\n        }\n        if ((token === import84.AppRootToken)) {\n            return this._AppRootToken_52;\n        }\n        if ((token === import67.DeepLinkConfigToken)) {\n            return this._DeepLinkConfigToken_53;\n        }\n        " + ifStatementOne + "\n        " + ifStatementTwo + "\n        if ((token === import34.Events)) {\n            return this._Events_56;\n        }\n        if ((token === import35.Form)) {\n            return this._Form_57;\n        }\n        if ((token === import36.Haptic)) {\n            return this._Haptic_58;\n        }\n        if ((token === import37.Keyboard)) {\n            return this._Keyboard_59;\n        }\n        if ((token === import38.LoadingController)) {\n            return this._LoadingController_60;\n        }\n        if ((token === import66.LocationStrategy)) {\n            return this._LocationStrategy_61;\n        }\n        if ((token === import39.Location)) {\n            return this._Location_62;\n        }\n        if ((token === import40.ModalController)) {\n            return this._ModalController_63;\n        }\n        if ((token === import41.PickerController)) {\n            return this._PickerController_64;\n        }\n        if ((token === import42.PopoverController)) {\n            return this._PopoverController_65;\n        }\n        if ((token === import43.SystemJsNgModuleLoader)) {\n            return this._SystemJsNgModuleLoader_66;\n        }\n        if ((token === import44.TapClick)) {\n            return this._TapClick_67;\n        }\n        if ((token === import45.ToastController)) {\n            return this._ToastController_68;\n        }\n        if ((token === import46.TransitionController)) {\n            return this._TransitionController_69;\n        }\n        if ((token === import85.ModuleLoader)) {\n            return this._ModuleLoader_70;\n        }\n        if ((token === import67.UrlSerializer)) {\n            return this._UrlSerializer_71;\n        }\n        if ((token === import68.DeepLinker)) {\n            return this._DeepLinker_72;\n        }\n        return notFoundResult;\n    }\n    destroyInternal() {\n        this._ApplicationRef__24.ngOnDestroy();\n        this._DomSharedStylesHost_31.ngOnDestroy();\n    }\n}\nexport const AppModuleNgFactory = new import0.NgModuleFactory(AppModuleInjector, import1.AppModule);\n//# sourceMappingURL=app.module.ngfactory.js.map\n      ";
            var appModuleNgFactoryPath = path_1.join(srcDir, 'app', 'app.module.ngfactory.js');
            var controllerPath = path_1.join(componentDir, 'action-sheet', 'action-sheet-controller.js');
            var controllerPath2 = path_1.join(componentDir, 'alert', 'alert-controller.js');
            // act
            var updatedContent = treeshake.purgeProviderControllerImportAndUsage(appModuleNgFactoryPath, knownContent, controllerPath);
            updatedContent = treeshake.purgeProviderControllerImportAndUsage(appModuleNgFactoryPath, updatedContent, controllerPath2);
            // assert
            expect(updatedContent).not.toEqual(knownContent);
            var relativeImportPathOne = helpers.toUnixPath(helpers.changeExtension(path_1.relative(nodeModulesDir, controllerPath), ''));
            var relativeImportPathTwo = helpers.toUnixPath(helpers.changeExtension(path_1.relative(nodeModulesDir, controllerPath2), ''));
            var importRegexOne = treeshake.generateWildCardImportRegex(relativeImportPathOne);
            var importRegexTwo = treeshake.generateWildCardImportRegex(relativeImportPathTwo);
            var importResultOne = importRegexOne.exec(updatedContent);
            var importResultTwo = importRegexTwo.exec(updatedContent);
            expect(updatedContent.indexOf("/*" + importResultOne[0] + "*/")).toBeGreaterThanOrEqual(0);
            expect(updatedContent.indexOf("/*" + importResultTwo[0] + "*/")).toBeGreaterThanOrEqual(0);
            var namedImportOne = importResultOne[1].trim();
            var namedImportTwo = importResultTwo[1].trim();
            var purgeGetterRegExOne = treeshake.generateRemoveGetterFromImportRegex(namedImportOne);
            var purgeGetterResultsOne = purgeGetterRegExOne.exec(updatedContent);
            var purgeIfRegExOne = treeshake.generateRemoveIfStatementRegex(namedImportOne);
            var purgeIfResultsOne = purgeIfRegExOne.exec(updatedContent);
            var purgeGetterRegExTwo = treeshake.generateRemoveGetterFromImportRegex(namedImportTwo);
            var purgeGetterResultsTwo = purgeGetterRegExTwo.exec(updatedContent);
            var purgeIfRegExTwo = treeshake.generateRemoveIfStatementRegex(namedImportTwo);
            var purgeIfResultsTwo = purgeIfRegExTwo.exec(updatedContent);
            expect(updatedContent.indexOf("/*" + purgeGetterResultsOne[0] + "*/")).toBeGreaterThanOrEqual(0);
            expect(updatedContent.indexOf("/*" + purgeIfResultsOne[0] + "*/")).toBeGreaterThanOrEqual(0);
            expect(updatedContent.indexOf("/*" + purgeGetterResultsTwo[0] + "*/")).toBeGreaterThanOrEqual(0);
            expect(updatedContent.indexOf("/*" + purgeIfResultsTwo[0] + "*/")).toBeGreaterThanOrEqual(0);
        });
    });
    describe('purgeProviderClassNameFromIonicModuleForRoot', function () {
        it('should purge the provider from the forRoot method object', function () {
            // arrange
            var classOne = "ModalController";
            var classTwo = "LoadingController";
            var knownContent = "\n        static forRoot(appRoot, config = null, deepLinkConfig = null) {\n        return {\n            ngModule: IonicModule,\n            providers: [\n                // useValue: bootstrap values\n                { provide: AppRootToken, useValue: appRoot },\n                { provide: ConfigToken, useValue: config },\n                { provide: DeepLinkConfigToken, useValue: deepLinkConfig },\n                // useFactory: user values\n                { provide: PlatformConfigToken, useFactory: providePlatformConfigs },\n                // useFactory: ionic core providers\n                { provide: Platform, useFactory: setupPlatform, deps: [DOCUMENT, PlatformConfigToken, NgZone] },\n                { provide: Config, useFactory: setupConfig, deps: [ConfigToken, Platform] },\n                // useFactory: ionic app initializers\n                { provide: APP_INITIALIZER, useFactory: registerModeConfigs, deps: [Config], multi: true },\n                { provide: APP_INITIALIZER, useFactory: setupProvideEvents, deps: [Platform, DomController], multi: true },\n                { provide: APP_INITIALIZER, useFactory: setupTapClick, deps: [Config, Platform, DomController, App, NgZone, GestureController], multi: true },\n                // useClass\n                // { provide: HAMMER_GESTURE_CONFIG, useClass: IonicGestureConfig },\n                // useValue\n                { provide: ANALYZE_FOR_ENTRY_COMPONENTS, useValue: appRoot, multi: true },\n                // ionic providers\n                ActionSheetController,\n                AlertController,\n                App,\n                DomController,\n                Events,\n                Form,\n                GestureController,\n                Haptic,\n                Keyboard,\n                " + classTwo + ",\n                Location,\n                MenuController,\n                " + classOne + ",\n                PickerController,\n                PopoverController,\n                SystemJsNgModuleLoader,\n                TapClick,\n                ToastController,\n                TransitionController,\n                { provide: ModuleLoader, useFactory: provideModuleLoader, deps: [DeepLinkConfigToken, SystemJsNgModuleLoader, Injector] },\n                { provide: LocationStrategy, useFactory: provideLocationStrategy, deps: [PlatformLocation, [new Inject(APP_BASE_HREF), new Optional()], Config] },\n                { provide: UrlSerializer, useFactory: setupUrlSerializer, deps: [DeepLinkConfigToken] },\n                { provide: DeepLinker, useFactory: setupDeepLinker, deps: [App, UrlSerializer, Location, DeepLinkConfigToken, ModuleLoader, ComponentFactoryResolver] },\n            ]\n        };\n    }\n}\n      ";
            // act
            var updatedContent = treeshake.purgeProviderClassNameFromIonicModuleForRoot(knownContent, classOne);
            updatedContent = treeshake.purgeProviderClassNameFromIonicModuleForRoot(updatedContent, classTwo);
            // assert
            expect(updatedContent).not.toEqual(knownContent);
            var regexOne = treeshake.generateIonicModulePurgeProviderRegex(classOne);
            var regexTwo = treeshake.generateIonicModulePurgeProviderRegex(classTwo);
            var resultsOne = regexOne.exec(updatedContent);
            var resultsTwo = regexTwo.exec(updatedContent);
            expect(updatedContent.indexOf("/*" + resultsOne[0] + "*/")).toBeGreaterThanOrEqual(0);
            expect(updatedContent.indexOf("/*" + resultsTwo[0] + "*/")).toBeGreaterThanOrEqual(0);
        });
    });
});
